## Version 0.1 (2017-08-15)

### New features

Initial release

### Bugs fixed

**Issues**

* [Issue 51](https://github.com/spyder-ide/spyder-reports/issues/51) - Release 0.1
* [Issue 46](https://github.com/spyder-ide/spyder-reports/issues/46) - Some fixes before 0.1 release
* [Issue 43](https://github.com/spyder-ide/spyder-reports/issues/43) - Save reports
* [Issue 40](https://github.com/spyder-ide/spyder-reports/issues/40) - Show some progress while report is rendering
* [Issue 39](https://github.com/spyder-ide/spyder-reports/issues/39) - Disambiguate report tabs
* [Issue 38](https://github.com/spyder-ide/spyder-reports/issues/38) - Render reports in Spyder's temp directory
* [Issue 36](https://github.com/spyder-ide/spyder-reports/issues/36) - Render welcome.md in Spyder's temp directory
* [Issue 34](https://github.com/spyder-ide/spyder-reports/issues/34) - Error at startup when opening welcome.html
* [Issue 32](https://github.com/spyder-ide/spyder-reports/issues/32) - Error when trying to display error message box
* [Issue 27](https://github.com/spyder-ide/spyder-reports/issues/27) - Error when rendering reports on Windows
* [Issue 26](https://github.com/spyder-ide/spyder-reports/issues/26) - Use check_compatibility to deactivate this plugin in Python 2
* [Issue 23](https://github.com/spyder-ide/spyder-reports/issues/23) - Add some content to the Welcome page
* [Issue 22](https://github.com/spyder-ide/spyder-reports/issues/22) - Add support for Pweave 0.30
* [Issue 14](https://github.com/spyder-ide/spyder-reports/issues/14) - Add usage and screenshot to Readme
* [Issue 13](https://github.com/spyder-ide/spyder-reports/issues/13) - Add basic tests and activate CI
* [Issue 12](https://github.com/spyder-ide/spyder-reports/issues/12) - Save file before rendering report
* [Issue 11](https://github.com/spyder-ide/spyder-reports/issues/11) - Add framed web view and share with terminal and help viewer
* [Issue 9](https://github.com/spyder-ide/spyder-reports/issues/9) - Create diferent tabs for each report
* [Issue 4](https://github.com/spyder-ide/spyder-reports/issues/4) - Use as basic structure, pylint plugin

In this release 19 issues were closed

**Pull requests**

* [PR 52](https://github.com/spyder-ide/spyder-reports/pull/52) - PR: Add Release instructions
* [PR 47](https://github.com/spyder-ide/spyder-reports/pull/47) - PR: Several release fixes
* [PR 45](https://github.com/spyder-ide/spyder-reports/pull/45) - PR: Save reports to disk
* [PR 44](https://github.com/spyder-ide/spyder-reports/pull/44) - PR: Show render progress and errors
* [PR 42](https://github.com/spyder-ide/spyder-reports/pull/42) - PR: Render reports in a temp dir
* [PR 41](https://github.com/spyder-ide/spyder-reports/pull/41) - PR: Disambiguate tabs
* [PR 37](https://github.com/spyder-ide/spyder-reports/pull/37) - PR: Use Spyder's temp directory to render our welcome file
* [PR 35](https://github.com/spyder-ide/spyder-reports/pull/35) - PR: Remove unnecessary reloading of welcome file output
* [PR 33](https://github.com/spyder-ide/spyder-reports/pull/33) - PR: Fix error with error messagebox
* [PR 31](https://github.com/spyder-ide/spyder-reports/pull/31) - PR: Add pandoc as a dependency in our tests
* [PR 30](https://github.com/spyder-ide/spyder-reports/pull/30) - PR: Install Spyder with pip on first CircleCI node
* [PR 29](https://github.com/spyder-ide/spyder-reports/pull/29) - PR: Render report in a thread.
* [PR 24](https://github.com/spyder-ide/spyder-reports/pull/24) - PR: Add some content to welcome and improve CI
* [PR 21](https://github.com/spyder-ide/spyder-reports/pull/21) - PR: Add screenshot to Readme
* [PR 20](https://github.com/spyder-ide/spyder-reports/pull/20) - PR: Improve Readme
* [PR 19](https://github.com/spyder-ide/spyder-reports/pull/19) - PR: Use a tabs per each file
* [PR 17](https://github.com/spyder-ide/spyder-reports/pull/17) - PR: Activate ciocheck in CI
* [PR 15](https://github.com/spyder-ide/spyder-reports/pull/15) - PR: Activate continuous integration
* [PR 8](https://github.com/spyder-ide/spyder-reports/pull/8) - PR: Pweave support
* [PR 7](https://github.com/spyder-ide/spyder-reports/pull/7) - PR: Create empty widget
* [PR 5](https://github.com/spyder-ide/spyder-reports/pull/5) - PR: Basic template

In this release 21 pull requests were merged
